starcluster.commands.completers

Package starcluster :: Package commands :: Module completers |
[hide private]
[frames] | no frames]

# Module completers

source code

Classes | [hide private]
| Completer Base class for all completer classes
| ClusterCompleter Returns a list of all cluster names as completion options
| NodeCompleter Returns a list of all node names as completion options
| ImageCompleter Returns a list of all registered image ids as completion options
| EBSImageCompleter Returns a list of all registered EBS image ids as completion options
| S3ImageCompleter Returns a list of all registered S3 image ids as completion options
| InstanceCompleter Returns a list of all instance ids as completion options
| VolumeCompleter Returns a list of all volume ids as completion options

Variables | [hide private]
| __package__ = ``'``starcluster.commands``'``